Struct extemp::Transition
[−]
[src]
pub struct Transition {
// some fields omitted
}A single allowable transition in a temporal automaton.
A transition goes from one state to another, and can imply actions to be taken when it occurs (e.g., clean up all automata).
Methods
impl Transition[src]
fn new(cause: Event, result: Action) -> Transition
fn epsilon() -> Transition